@@ -15,10 +15,11 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 import os
 import subprocess
-from typing import Any, Dict, Iterable, List, Optional, Union
+from typing import Any, Iterable, Mapping
 
 from pinotdb import connect
 
@@ -102,24 +103,24 @@ class PinotAdminHook(BaseHook):
 
     def create_segment(
         self,
-        generator_config_file: Optional[str] = None,
-        data_dir: Optional[str] = None,
-        segment_format: Optional[str] = None,
-        out_dir: Optional[str] = None,
-        overwrite: Optional[str] = None,
-        table_name: Optional[str] = None,
-        segment_name: Optional[str] = None,
-        time_column_name: Optional[str] = None,
-        schema_file: Optional[str] = None,
-        reader_config_file: Optional[str] = None,
-        enable_star_tree_index: Optional[str] = None,
-        star_tree_index_spec_file: Optional[str] = None,
-        hll_size: Optional[str] = None,
-        hll_columns: Optional[str] = None,
-        hll_suffix: Optional[str] = None,
-        num_threads: Optional[str] = None,
-        post_creation_verification: Optional[str] = None,
-        retry: Optional[str] = None,
+        generator_config_file: str | None = None,
+        data_dir: str | None = None,
+        segment_format: str | None = None,
+        out_dir: str | None = None,
+        overwrite: str | None = None,
+        table_name: str | None = None,
+        segment_name: str | None = None,
+        time_column_name: str | None = None,
+        schema_file: str | None = None,
+        reader_config_file: str | None = None,
+        enable_star_tree_index: str | None = None,
+        star_tree_index_spec_file: str | None = None,
+        hll_size: str | None = None,
+        hll_columns: str | None = None,
+        hll_suffix: str | None = None,
+        num_threads: str | None = None,
+        post_creation_verification: str | None = None,
+        retry: str | None = None,
     ) -> Any:
         """Create Pinot segment by run CreateSegment command"""
         cmd = ["CreateSegment"]
@@ -180,7 +181,7 @@ class PinotAdminHook(BaseHook):
 
         self.run_cli(cmd)
 
-    def upload_segment(self, segment_dir: str, table_name: Optional[str] = None) -> Any:
+    def upload_segment(self, segment_dir: str, table_name: str | None = None) -> Any:
         """
         Upload Segment with run UploadSegment command
 
@@ -196,7 +197,7 @@ class PinotAdminHook(BaseHook):
             cmd += ["-tableName", table_name]
         self.run_cli(cmd)
 
-    def run_cli(self, cmd: List[str], verbose: bool = True) -> str:
+    def run_cli(self, cmd: list[str], verbose: bool = True) -> str:
         """
         Run command with pinot-admin.sh
 
@@ -275,7 +276,9 @@ class PinotDbApiHook(DbApiHook):
         endpoint = conn.extra_dejson.get('endpoint', 'query/sql')
         return f'{conn_type}://{host}/{endpoint}'
 
-    def get_records(self, sql: str, parameters: Optional[Union[Dict[str, Any], Iterable[Any]]] = None) -> Any:
+    def get_records(
+        self, sql: str | list[str], parameters: Iterable | Mapping | None = None, **kwargs
+    ) -> Any:
         """
         Executes the sql and returns a set of records.
 
@@ -287,7 +290,7 @@ class PinotDbApiHook(DbApiHook):
             cur.execute(sql)
             return cur.fetchall()
 
-    def get_first(self, sql: str, parameters: Optional[Union[Dict[str, Any], Iterable[Any]]] = None) -> Any:
+    def get_first(self, sql: str | list[str], parameters: Iterable | Mapping | None = None) -> Any:
         """
         Executes the sql and returns the first resulting row.
 
@@ -306,7 +309,7 @@ class PinotDbApiHook(DbApiHook):
         self,
         table: str,
         rows: str,
-        target_fields: Optional[str] = None,
+        target_fields: str | None = None,
         commit_every: int = 1000,
         replace: bool = False,
         **kwargs: Any,
